summaryrefslogtreecommitdiffstats
path: root/libkdepim/sidebarextension.h
diff options
context:
space:
mode:
Diffstat (limited to 'libkdepim/sidebarextension.h')
-rw-r--r--libkdepim/sidebarextension.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/libkdepim/sidebarextension.h b/libkdepim/sidebarextension.h
index 98b185c1..e5551ff6 100644
--- a/libkdepim/sidebarextension.h
+++ b/libkdepim/sidebarextension.h
@@ -46,10 +46,10 @@ namespace KParts
*
* @param exported A TQWidget derived widget that will be provided for the
* users of SideBarExtension.
* @param tqparent The tqparent widget.
* @param name The name of the class.
**/
- SideBarExtension(TQWidget *exported, KParts::ReadOnlyPart *tqparent, const char* name);
+ SideBarExtension(TQWidget *exported, KParts::ReadOnlyPart *parent, const char* name);
~SideBarExtension();
/**
@@ -46,10 +46,10 @@ namespace KParts
* @param exported A TQWidget derived widget that will be provided for the
* users of SideBarExtension.
- * @param tqparent The tqparent widget.
+ * @param parent The parent widget.
* @param name The name of the class.
**/